webview_all library

Classes

HttpAuthRequest
Defines the parameters of a pending HTTP authentication request received by the webview through a HttpAuthRequestCallback.
HttpResponseError
Error returned in PlatformNavigationDelegate.setOnHttpError when an HTTP response error has been received.
JavaScriptAlertDialogRequest
Defines the parameters that support PlatformWebViewController.setOnJavaScriptAlertDialog.
JavaScriptConfirmDialogRequest
Defines the parameters that support PlatformWebViewController.setOnJavaScriptConfirmDialog.
JavaScriptConsoleMessage
Represents a console message written to the JavaScript console.
JavaScriptInvocationParams
Parameters for invoking an asynchronous JavaScript function.
JavaScriptMessage
A message that was sent by JavaScript code running in a WebView.
JavaScriptTextInputDialogRequest
Defines the parameters that support PlatformWebViewController.setOnJavaScriptTextInputDialog.
Callbacks for accepting or rejecting navigation changes, and for tracking the progress of navigation requests.
Defines the parameters of the pending navigation callback.
OffscreenWebViewSession
Owns a WebViewController used without a WebViewWidget.
PlatformNavigationDelegateCreationParams
Object specifying creation parameters for creating a PlatformNavigationDelegate.
PlatformWebViewControllerCreationParams
Object specifying creation parameters for creating a PlatformWebViewController.
PlatformWebViewCookieManagerCreationParams
Object specifying creation parameters for creating a PlatformWebViewCookieManager.
PlatformWebViewDataManagerCreationParams
Creation parameters for a platform WebView data manager.
PlatformWebViewPermissionRequest
Permissions request when web content requests access to protected resources.
PlatformWebViewWidgetCreationParams
Object specifying creation parameters for creating a WebViewWidgetDelegate.
ScrollPositionChange
Defines the parameters of the scroll position change callback.
SslAuthError
Represents an SSL error with the associated certificate.
UrlChange
Details of the change to a web view's url.
WebResourceError
Error returned in WebView.onWebResourceError when a web resource loading error has occurred.
WebResourceRequest
Defines the parameters of the web resource request from the associated request.
WebResourceResponse
Contains information about the response for a request.
WebViewController
Controls a WebView provided by the host platform.
WebViewCookie
A cookie that can be set globally for all web views using WebViewCookieManagerPlatform.
WebViewCookieManager
Manages cookies pertaining to all WebViews.
WebViewCredential
Defines the response parameters of a pending HttpAuthRequest received by the webview.
WebViewDataClearingResult
The result of clearing website data from a WebView data store.
WebViewDataManager
Manages website data shared by WebViews in the current platform data store.
WebViewPermissionRequest
Permissions request when web content requests access to protected resources.
WebViewPermissionResourceType
Types of resources that can require permissions.
WebViewPlatform
Interface for a platform implementation of a WebView.
WebViewUserScript
A script registered for injection into future documents.
WebViewWidget
Displays a native WebView as a Widget.
X509Certificate
Represents an X.509 certificate.

Enums

JavaScriptLogLevel
Represents the severity of a JavaScript log message.
JavaScriptMode
Describes the state of JavaScript support in a given web view.
LoadRequestMethod
Defines the supported HTTP methods for loading a page in PlatformWebViewController.
A decision on how to handle a navigation request.
WebResourceErrorType
Possible error type categorizations used by WebResourceError.
WebViewDataType
A category of persistent or session website data used by WebViews.
WebViewOverScrollMode
Defines the over-scroll behavior of a WebView.
WebViewUserScriptInjectionTime
The lifecycle point at which a user script is injected.

Typedefs

HttpResponseErrorCallback = void Function(HttpResponseError error)
Signature for callbacks that report http errors during loading a page.
Signature for callbacks that report a pending navigation request.
PageEventCallback = void Function(String url)
Signature for callbacks that report page events triggered by the native web view.
ProgressCallback = void Function(int progress)
Signature for callbacks that report loading progress of a page.
WebResourceErrorCallback = void Function(WebResourceError error)
Signature for callbacks that report a resource loading error.

Exceptions / Errors

JavaScriptExecutionException
An error thrown or rejected by an asynchronous JavaScript invocation.