OffscreenWebViewSession class

Owns a WebViewController used without a WebViewWidget.

Closing the session deterministically releases its platform resources. The controller must not be retained or used after close starts.

Properties

controller WebViewController
The controller owned by this session.
no setter
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether close has started.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Permanently releases the controller and its platform resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({void onPermissionRequest(WebViewPermissionRequest request)?}) Future<OffscreenWebViewSession>
Creates an offscreen session with default controller parameters.
fromController(WebViewController controller) Future<OffscreenWebViewSession>
Transfers ownership of controller to a new offscreen session.
fromPlatformCreationParams(PlatformWebViewControllerCreationParams params, {void onPermissionRequest(WebViewPermissionRequest request)?}) Future<OffscreenWebViewSession>
Creates an offscreen session with platform-specific controller params.