WebViewDataClearingResult class
The result of clearing website data from a WebView data store.
- Annotations
Constructors
-
WebViewDataClearingResult({Set<
WebViewDataType> clearedDataTypes = const <WebViewDataType>{}, Set<WebViewDataType> unsupportedDataTypes = const <WebViewDataType>{}, Map<WebViewDataType, String> failures = const <WebViewDataType, String>{}}) - Creates a website data clearing result.
Properties
-
clearedDataTypes
→ Set<
WebViewDataType> -
Data categories whose native clearing operation completed successfully.
final
-
failures
→ Map<
WebViewDataType, String> -
Data categories that could not be cleared and their diagnostic messages.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
Whether every website data category was cleared successfully.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unsupportedDataTypes
→ Set<
WebViewDataType> -
Data categories that the current platform cannot clear through this API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited